@@ -38,8 +38,8 @@ def _handle_req_ret(period, report_type, code, market):
         "stockCode": code,
         "stockMarket": this_market
     }
-
-    _df_ = total_handle_req(body=body, URL=BASIC_FIN_POST_URL)
+    update_url = lambda url: url.replace("__kaisarooturl__", KAISA_ROOT_URL)
+    _df_ = total_handle_req(body=body, URL=update_url(BASIC_FIN_POST_URL))
     return _df_
 
 def get_basic_fin_data(code='00700', market=2, period=12):
@@ -140,7 +140,8 @@ def _handle_ex_ret(code_list=['00700'], queryType=None, start_date=None, end_dat
             "current": page
         }
 
-    df_ = total_handle_req(body=body, URL=EX_FIN_POST_URL)
+    update_url = lambda url: url.replace("__kaisarooturl__", KAISA_ROOT_URL)
+    df_ = total_handle_req(body=body, URL=update_url(EX_FIN_POST_URL))
 
     return df_
 
