@@ -1,19 +1,13 @@
 # -*- coding: utf-8 -*-
-
-import sys, json, time, struct, datetime
+import sys, json, time, struct
 from os.path import dirname, abspath
 from google.protobuf import json_format
+SERVER = r'\py_protoc' if ('win' in sys.platform) else r'/py_protoc'
 project_path = dirname(dirname(abspath(__file__)))
-projec_full_path = project_path + r'\py_protoc'
+projec_full_path = project_path + SERVER
 sys.path.append(projec_full_path)
 from pub_cls_com import *
 from com import *
-############################旧版################################
-# from py_protoc import msg_stock_pb2 as msg_stock
-# from py_protoc import msg_stock_pb2 as msg_stock
-# from py_protoc import msg_stock_common_pb2 as msg_stock_common
-############################旧版################################
-
 from py_protoc import msg_comm_request_pb2 as msg_stock_common
 from py_protoc import msg_comm_cust_pb2 as cust_pb
 from py_protoc import msg_comm_response_pb2 as reponse_pb
@@ -181,8 +175,8 @@ class KaisaProtoc(object):
         ## 解析quote-data
         sec = quote.quote_time.seconds
         nano = quote.quote_time.nanos
-        # up_t = datetime.datetime.fromtimestamp((sec + nano / 1000000000.0))
         update_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(sec + nano / 1000000000.0))
+
         return {'market': quote.market,
                 'code': quote.code,
                 'now': quote.now,
