@@ -53,7 +53,8 @@ def _handle_ex_ret(code_list=['00700'], queryType=None, start_date=None, end_dat
         "current": page,
         "size": 100
     }
-    df_ = total_handle_req(body=body, URL=BE_TECH_POST_URL)
+    update_url = lambda url: url.replace("__kaisarooturl__", KAISA_ROOT_URL)
+    df_ = total_handle_req(body=body, URL=update_url(BE_TECH_POST_URL))
 
     return df_
 
